@@ -26,6 +26,9 @@ extern "C" {
 #define WC_DISCARDNS 0x00000010
 #define WC_SEPCHARS 0x00000020
 #define WC_DEFAULTCHAR 0x00000040
+#if (_WIN32_WINNT >= 0x0600)
+#define WC_ERR_INVALID_CHARS 0x00000080
+#endif
 #define WC_NO_BEST_FIT_CHARS 0x00000400
 
 #define CT_CTYPE1 0x00000001
@@ -1016,14 +1019,6 @@ WINBASEAPI LCID WINAPI LocaleNameToLCID(
   DWORD dwFlags
 );
 
-WINBASEAPI int WINAPI NormalizeString(
-  NORM_FORM NormForm,
-  LPCWSTR lpSrcString,
-  int cwSrcLength,
-  LPWSTR lpDstString,
-  int cwDstLength
-);
-
 WINBASEAPI WINBOOL WINAPI RtlIsValidLocaleName(
   LPCWSTR LocaleName,
   ULONG Flags
